@@ -24,10 +24,8 @@ import matplotlib.pyplot as pl
 
 import pysiaf
 from pysiaf.utils import tools, compare
-from pysiaf.utils.enhanced_aperture_file import create_enhanced_aperture_file
-
 from pysiaf.constants import JWST_SOURCE_DATA_ROOT, JWST_TEMPORARY_DATA_ROOT, \
-    JWST_DELIVERY_DATA_ROOT, JWST_PRD_DATA_ROOT
+    JWST_DELIVERY_DATA_ROOT
 from pysiaf import iando
 from pysiaf.aperture import DISTORTION_ATTRIBUTES
 
@@ -135,7 +133,7 @@ for AperName in aperture_name_list:
     parent_apertures = siaf_aperture_definitions['parent_apertures'][index]
     dependency_type = siaf_aperture_definitions['dependency_type'][index]
 
-    if parent_apertures is not None: 
+    if parent_apertures is not None:
 
         if dependency_type in ['default', 'wedge', 'dhspil_wedge']:
             aperture._parent_apertures = parent_apertures
@@ -156,10 +154,8 @@ for AperName in aperture_name_list:
                 # compute V2Ref, V3Ref, distortion from XDetRef and YDetRef of aperture, based on the parent_aperture
                 aperture = tools.set_reference_point_and_distortion(instrument, aperture, parent_aperture)
 
-            if dependency_type != 'default':
-                sca_name = aperture.AperName[0:5]
-
             if dependency_type == 'wedge':
+                sca_name = aperture.AperName[0:5]
                 if (sca_name == 'NRCA5') and (('MASK335R' in aperture.AperName) or ('MASK430R' in aperture.AperName)):
                     # see https://jira.stsci.edu/browse/JWSTSIAF-77
                     sca_name += '335R430R'
@@ -168,15 +164,7 @@ for AperName in aperture_name_list:
                 aperture.V2Ref += v2_offset
                 aperture.V3Ref += v3_offset
             elif dependency_type == 'dhspil_wedge':
-                if sca_name == 'NRCA3':
-                    aperture.V2Ref += -1.582
-                    aperture.V3Ref += 39.918
-                elif sca_name == 'NRCB4':
-                    aperture.V2Ref += 1.196
-                    aperture.V3Ref += 39.967
-                else:
-                    print('dhspil_wedge aperture not supported')
-                    assert False
+                aperture.V3Ref += 43.
 
             aperture.complement()
 
@@ -293,7 +281,7 @@ for AperName in aperture_name_list:
                 setattr(aperture, 'XIdlVert{:d}'.format(j + 1), corners_Idl_x[j])
                 setattr(aperture, 'YIdlVert{:d}'.format(j + 1), corners_Idl_y[j])
 
-        elif dependency_type == 'grism_ts_sw':
+        elif dependency_type == 'grism_f444w':
             aperture._parent_apertures = [s.strip() for s in parent_apertures.split(';')]
 
             # the SCA on which this aperture is located
@@ -301,14 +289,14 @@ for AperName in aperture_name_list:
             for attribute in 'DetSciYAngle Sci2IdlDeg DetSciParity VIdlParity'.split():
                 setattr(aperture, attribute, getattr(master_aperture, attribute))
 
-            # the aperture on the LW channel whose V2Ref, V3Ref should be matched
-            LW_aperture = aperture_dict[aperture._parent_apertures[1]]
+            # the aperture on A5 whose V2Ref, V3Ref should be matched
+            a5_aperture = aperture_dict[aperture._parent_apertures[1]]
 
             # compute V2Ref, V3Ref, distortion from XDetRef and YDetRef of aperture, based on the parent_aperture
             aperture = tools.set_reference_point_and_distortion(instrument, aperture, master_aperture)
 
-            # modify aperture so that V2Ref, V3Ref match the LW_aperture
-            aperture = tools.match_v2v3(copy.deepcopy(LW_aperture), copy.deepcopy(aperture),
+            # modify aperture so that V2Ref, V3Ref match the a5_aperture
+            aperture = tools.match_v2v3(copy.deepcopy(a5_aperture), copy.deepcopy(aperture),
                                         verbose=False, match_v2_only=True)
 
             aperture.complement()
@@ -366,16 +354,11 @@ if emulate_delivery:
     for compare_to in [pysiaf.JWST_PRD_VERSION]:
         if compare_to == 'outdated pre-delivery':
             ref_siaf = pysiaf.Siaf(instrument, filename=os.path.join(pre_delivery_dir, 'NIRCam_SIAF_outdated.xml'))
-        elif compare_to == 'PRDOPSSOC-027':
-            ref_siaf = pysiaf.Siaf(instrument, filename=os.path.join(pre_delivery_dir, 'NIRCam_SIAF-027.xml'))
-        elif compare_to == 'PRDOPSSOC-M-026':
-            ref_siaf = pysiaf.Siaf(instrument, filename=os.path.join(JWST_PRD_DATA_ROOT.replace(
-                pysiaf.JWST_PRD_VERSION, compare_to), 'NIRCam_SIAF.xml'))
         else:
             # compare new SIAF with PRD version
             ref_siaf = pysiaf.Siaf(instrument)
 
-        tags = {'reference': compare_to, 'comparison': 'pre-delivery'}
+        tags = {'reference': compare_to, 'comparison': 'new pre-delivery'}
 
         compare.compare_siaf(pre_delivery_siaf, reference_siaf_input=ref_siaf,
                              fractional_tolerance=1e-6, report_dir=pre_delivery_dir, tags=tags)
@@ -386,13 +369,15 @@ if emulate_delivery:
         compare.compare_inspection_figures(pre_delivery_siaf, reference_siaf_input=ref_siaf,
                                            report_dir=pre_delivery_dir, tags=tags, mark_ref=True)
 
-        create_jira_plots = True
+        create_jira_plots = False
         if create_jira_plots:
-            # # make figures for JWSTSIAF-206 Jira ticket
-            selected_aperture_names = [['NRCA1_FULL_WEDGE_BAR','NRCA2_FULL_WEDGE_BAR','NRCA3_FULL_WEDGE_BAR','NRCA4_FULL_WEDGE_BAR','NRCA5_FULL_WEDGE_BAR',
-                                        'NRCA2_MASK210R','NRCA4_MASKSWB','NRCA5_MASK335R','NRCA5_MASK430R','NRCA5_MASKLWB'],
-                                       ['NRCA1_FULL_WEDGE_RND','NRCA2_FULL_WEDGE_RND','NRCA3_FULL_WEDGE_RND','NRCA4_FULL_WEDGE_RND','NRCA5_FULL_WEDGE_RND',
-                                       'NRCA2_MASK210R','NRCA4_MASKSWB','NRCA5_MASK335R','NRCA5_MASK430R','NRCA5_MASKLWB']
+
+            # # make figures for JWSTSIAF-160 Jira ticket
+            selected_aperture_names = [['NRCA2_MASK210R', 'NRCA2_FULL_MASK210R',
+                                        'NRCA5_MASK335R','NRCA5_FULL_MASK335R',
+                                        'NRCA5_MASK430R','NRCA5_FULL_MASK430R',
+                                        'NRCA2_FULL_WEDGE_RND','NRCA4_FULL_WEDGE_BAR','NRCA5_FULL_WEDGE_RND','NRCA5_FULL_WEDGE_BAR'
+                                        ]
                                        ]
 
             for selected_aperture_name in selected_aperture_names:
@@ -403,16 +388,10 @@ if emulate_delivery:
                                                    label=True)
                 pl.close('all')  # stops system from being overwhelmed with too may plots
 
-    #If desired, create the enhanced aperture file containing OSS corners as well as V2/V3 positions of the reference point
-    enhanced_aperture_file =  True
-    
-    if enhanced_aperture_file:
-        create_enhanced_aperture_file(aperture_dict)    
-
     # run some tests on the new SIAF
     from pysiaf.tests import test_aperture
     print('\nRunning aperture_transforms test for pre_delivery_siaf')
-    test_aperture.test_jwst_aperture_transforms([pre_delivery_siaf], verbose=False, threshold=0.11)
+    test_aperture.test_jwst_aperture_transforms([pre_delivery_siaf], verbose=False, threshold=0.1)
     print('\nRunning aperture_vertices test for pre_delivery_siaf')
     test_aperture.test_jwst_aperture_vertices([pre_delivery_siaf])
 
